@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 import numpy as np
 import pandas as pd
 
@@ -15,7 +15,7 @@ from ..validations import validate_series_has_time_index, validate_series_is_not
 
 @check_types
 def _point_density(data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m")) -> pd.Series:
-    """Point density
+    """Point density.
 
     Counts the number of points on a rolling time window.
 
@@ -27,7 +27,6 @@ def _point_density(data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m
     Returns:
         pd.Series: Time series with the point density for each rolling window.
     """
-
     return data.rolling(time_window, min_periods=1).count()
 
 
@@ -38,7 +37,7 @@ def low_density_identification_z_scores(
     cutoff: float = -3.0,
     test_normality_assumption: bool = False,
 ) -> pd.Series:
-    """Low density, Z-scores
+    """Low density, Z-scores.
 
     Detect periods with low density of data points using `Z-scores <https://en.wikipedia.org/wiki/Standard_score>`_. Z-score stands for
     the number of standard deviations by which the value of a raw score (i.e., an observed value or data point) is
@@ -47,13 +46,13 @@ def low_density_identification_z_scores(
 
     Args:
         data: Time series
-        time_window: Rolling window
-            Length of the time period to compute the density of points. Defaults to 5min.
-        cutoff: Cut-off
+        time_window: Rolling window.
+            Length of the time period to compute the density of points. Defaults to 5 min.
+        cutoff: Cut-off.
             Number of standard deviations from the mean.
             Low density periods are detected if the Z-score is below this cut-off value. Default -3.0.
-        test_normality_assumption: Test for normality
-            Raise a warning if the data is not normally distributed.
+        test_normality_assumption: Test for normality.
+            Raises an error if the data densities over the rolling windows are not normally distributed.
             The Shapiro-Wilk test is used. The test is only performed if the time series contains less than 5000 data points.
             Default to False.
 
@@ -87,16 +86,16 @@ def low_density_identification_z_scores(
 def low_density_identification_modified_z_scores(
     data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m"), cutoff: float = -3.5
 ) -> pd.Series:
-    """Low density, mod.Z-scores
+    """Low density, mod.Z-scores.
 
-    Detect periods with low density of data points using modified Z-scores.
+    Detect periods with a low density of data points using modified Z-scores.
     Low density periods are defined as time periods where the Z-score is lower than the cutoff.
 
     Args:
         data: Time series
-        time_window: Rolling window
-            Length of the time period to compute the density of points. Defaults to 5min.
-        cutoff: Cut-off
+        time_window: Rolling window.
+            Length of the time period to compute the density of points. Defaults to 5 min.
+        cutoff: Cut-off.
             Low density periods are detected if the modified Z-score is below this cut-off value. Default -3.5.
 
     Returns:
@@ -123,17 +122,17 @@ def low_density_identification_modified_z_scores(
 
 @check_types
 def low_density_identification_iqr(data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m")) -> pd.Series:
-    """Low density, IQR
+    """Low density, IQR.
 
-    Detect periods with low density of data points using the `interquartile range (IQR)
+    Detect periods with a low density of data points using the `interquartile range (IQR)
     <https://en.wikipedia.org/wiki/Interquartile_range>`_ method. The IQR is a measure of statistical
     dispersion, which is the spread of the data. Densities that are more than 1.5 IQR below Q1 are considered
     as low density periods in the data.
 
     Args:
         data: time series
-        time_window: Rolling window
-            Length of the time period to compute the density of points. Defaults to 5min.
+        time_window: Rolling window.
+            Length of the time period to compute the density of points. Defaults to 5 min.
 
     Returns:
         pd.Series: time series
@@ -165,16 +164,16 @@ def low_density_identification_iqr(data: pd.Series, time_window: pd.Timedelta =
 def low_density_identification_threshold(
     data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m"), cutoff: int = 10
 ) -> pd.Series:
-    """Low density, threshold
+    """Low density, threshold.
 
-    Detect periods with low density of points using a time delta threshold as a cut-off value.
+    Detect periods with a low density of points using a time delta threshold as a cut-off value.
 
     Args:
         data: time series
-        time_window: Rolling window
-            Length of the time period to compute the density of points. Defaults to 5min.
-        cutoff: Density cut-off
-            Low density periods are detected if the number of points is less than this cut-off value. Default 10.
+        time_window: Rolling window.
+            Length of the time period to compute the density of points. Defaults to 5 min.
+        cutoff: Density cut-off.
+            Low density periods are detected if the number of points is less than this cut-off value. Default is 10.
 
     Returns:
         pd.Series: time series
@@ -184,7 +183,6 @@ def low_density_identification_threshold(
         UserTypeError: data is not a time series
         UserValueError: data is empty
     """
-
     validate_series_has_time_index(data)
     validate_series_is_not_empty(data)
 
