@@ -1,5 +1,4 @@
 # Copyright 2022 Cognite AS
-
 import numba
 import numpy as np
 import pandas as pd
@@ -24,7 +23,7 @@ def _validate_threshold(threshold: float):
 
 @numba.njit
 def _prolong_indicator(x_value: np.array, x_indicator: np.array) -> np.array:
-    """Indicator adjustment
+    """Indicator adjustment.
 
     Function that prolongs the indicator value for bad data quality - indicator will be set to 1 for as long as data doesn't go back to "normal" (ie., back to the value it had before the value decreased).
 
@@ -35,7 +34,6 @@ def _prolong_indicator(x_value: np.array, x_indicator: np.array) -> np.array:
     Returns:
          np.array: Indicator time series
     """
-
     i, n = 0, len(x_value)
 
     while i < n - 1:
@@ -53,9 +51,9 @@ def _prolong_indicator(x_value: np.array, x_indicator: np.array) -> np.array:
 
 @check_types
 def negative_running_hours_check(x: pd.Series, threshold: float = 0.0) -> pd.Series:
-    """Negative running hours
+    """Negative running hours.
 
-    Negative running hours model is created in order to automate data quality check for time series with values that
+    The negative running hours model is created in order to automate data quality check for time series with values that
     shouldn't be decreasing over time. One example would be Running Hours (or Hour Count) time series - a specific type
     of time series that is counting the number of running hours in a pump. Given that we expect the number of running
     hours to either stay the same (if the pump is not running) or increase with time (if the pump is running), the
@@ -67,7 +65,7 @@ def negative_running_hours_check(x: pd.Series, threshold: float = 0.0) -> pd.Ser
         x: Time series
         threshold: Threshold for value drop.
             This threshold indicates for how many hours the time series value needs to drop (in hours) before we
-            consider it bad data quality. Threshold must be a non-negative float. By default, the threshold is set to 0.
+            consider it bad data quality. The threshold must be a non-negative float. By default, the threshold is set to 0.
 
     Returns:
         pandas.Series: Time series
@@ -83,9 +81,7 @@ def negative_running_hours_check(x: pd.Series, threshold: float = 0.0) -> pd.Ser
         UserValueError: index of x is not increasing
         UserTypeError: threshold is not a number
         UserValueError: threshold is a negative number
-
     """
-
     _validate_time_series(x)
 
     _validate_threshold(threshold)
