@@ -11,12 +11,12 @@ from ..validations import validate_series_has_minimum_length
 
 @check_types
 def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167, poly_order: int = 3):
-    r"""Extreme outliers removal
+    r"""Extreme outliers removal.
 
     Outlier detector and removal based on the `paper from Gustavo A. Zarruk
     <https://iopscience.iop.org/article/10.1088/0957-0233/16/10/012/meta>`_. The procedure is as follows:
 
-         * Fit a polynomial curve to the model using all of the data
+         * Fit a polynomial curve to the model using all the data
          * Calculate the studentized deleted (or externally studentized) residuals
          * These residuals follow a t distribution with degrees of freedom n - p - 1
          * Bonferroni critical value can be computed using the significance level (alpha) and t distribution
@@ -28,10 +28,10 @@ def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167,
     Args:
         data: Time Series.
         alpha: Significance level.
-            is a number higher than or equal to 0 and lower than 1. In statistics, the significance level is the
+            This is a number higher than or equal to 0 and lower than 1. In statistics, the significance level is the
             probability of rejecting the null hypothesis when true. For example, a significance level of 0.05 means that
             there is a 5% risk detecting an outlier that is not a true outlier.
-        bc_relaxation: Relaxation factor.
+        bc_relaxation: Relaxation factor
             for the Bonferroni critical value. Smaller values will make anomaly detection more conservative. Defaults
             to 1/6.
         poly_order: Polynomial order.
@@ -44,7 +44,6 @@ def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167,
     Raises:
         UserValueError: Alpha must be a number between 0 and 1
     """
-
     # Check inputs
     data = data.dropna()
 
