@@ -19,14 +19,16 @@ from ..base import DataQualityScore, DataQualityScoreAnalyser
 
 
 class DensityDataQualityScoreAnalyser(DataQualityScoreAnalyser):
+    """Density based data quality scores."""
+
     @check_types
     def __init__(self, series: pd.Series):
-        """Density based data quality scores
+        """Density data quality score analyser init function.
 
         Args:
             series: Series to be analysed
 
-        raises:
+        Raises:
             UserValueError: If the series has less than 2 values
             UserValueError: If series has no time index
         """
@@ -46,7 +48,7 @@ class DensityDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         low_density_detection_method: Literal["iqr", "z_scores", "modified_z_scores", "threshold"] = "iqr",
         **low_density_detection_options: Optional[Union[pd.Timedelta, int, bool]],
     ) -> DataQualityScore:
-        """Compute the low density analysis score
+        """Compute the low density analysis score.
 
         Args:
             analysis_start: Analyis start time
@@ -59,7 +61,7 @@ class DensityDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         Returns:
             DataQualityScore: A DataQualityScore object
 
-        raises:
+        Raises:
             UserValueError: If analysis_start < analysis_end
             UserValueError: If the analysis start and end timestamps are outside the range of the series index
         """
