@@ -17,14 +17,16 @@ from ..base import DataQualityScore, DataQualityScoreAnalyser
 
 
 class GapDataQualityScoreAnalyser(DataQualityScoreAnalyser):
+    """Gap based data quality scores."""
+
     @check_types
     def __init__(self, series: pd.Series):
-        """Gap based data quality scores
+        """Gap based data quality scores init function.
 
         Args:
             series: Series to be analysed
 
-        raises:
+        Raises:
             UserValueError: If the series has less than 2 values
             UserValueError: If series has no time index
         """
@@ -44,7 +46,7 @@ class GapDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         gap_detection_method: Literal["iqr", "z_scores", "modified_z_scores", "threshold"] = "iqr",
         **gap_detection_options: Optional[Union[pd.Timedelta, int, bool]],
     ) -> DataQualityScore:
-        """Compute the gap analysis score
+        """Compute the gap analysis score.
 
         Args:
             analysis_start: Analyis start time
@@ -57,11 +59,10 @@ class GapDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         Returns:
             DataQualityScore: A GapDataQualityScore object
 
-        raises:
+        Raises:
             UserValueError: If analysis_start < analysis_end
             UserValueError: If the analysis start and end timestamps are outside the range of the series index
         """
-
         super().compute_score(analysis_start, analysis_end)
         # Treat empty series as one gap
         if len(self.series) == 0:
