@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 from typing import Callable, List
 
 import numpy as np
@@ -15,20 +15,20 @@ from ..validations import validate_series_has_time_index
 
 @check_types
 def cpd_ed_pelt(data: pd.Series, min_distance: int = 1) -> pd.Series:
-    """Change Point Detection
+    """Change Point Detection.
 
-    Detect change points in a time series. The time series is split into "statistically homogeneous" segments using the
+    This function detects change points in a time series. The time series is split into "statistically homogeneous" segments using the
     ED Pelt change point detection algorithm while observing the minimum distance argument.
 
     Args:
         data: Time series
 
-        min_distance: Minimum distance
+        min_distance: Minimum distance.
             Specifies the minimum point wise distance for each segment that will be considered in the Change
             Point Detection algorithm.
 
     Returns:
-        pandas.Series: Time series
+        pandas.Series: Time series.
         Binary time series.
     """
     validate_series_has_time_index(data)
@@ -70,7 +70,8 @@ def cpd_ed_pelt(data: pd.Series, min_distance: int = 1) -> pd.Series:
 
 
 def get_partial_sums(data: np.ndarray, k: int) -> np.ndarray:
-    """
+    """Partial sums.
+
     Partial sums for empirical CDF (formula (2.1) from Section 2.1 "Model" in [Haynes2017])
 
     Args:
@@ -133,7 +134,7 @@ def get_segment_cost(partial_sums: np.ndarray, tau1: int, tau2: int, k: int, n:
 def ed_pelt(data: np.ndarray, min_distance: int = 1) -> np.ndarray:
     """The ED-PELT algorithm for change point detection.
 
-    For given array of `float` values, detects locations of change points that splits original series of values into
+    For a given array of `float` values, this algorithm detects locations of change points that splits original series of values into
     "statistically homogeneous" segments. Such points correspond to moments when statistical properties of the
     distribution are changing. This method supports nonparametric distributions and has O(N*log(N)) algorithmic
     complexity.
