@@ -10,12 +10,12 @@ from ..validations import validate_series_has_time_index, validate_series_is_not
 
 
 class Cusum:
-    """Cumulative sum (CUSUM)
+    """Cumulative sum (CUSUM).
 
     This technique calculates the cumulative sum of positive and negative changes (g+t and g−t) in the data (x) and compares them to a threshold.
-    When this threshold is exceeded a change is detected (time_talarm) and the cumulative sum restarts from zero.
+    When this threshold is exceeded, a change is detected (time_talarm), and the cumulative sum restarts from zero.
     To avoid the detection of a change in absence of an actual change or a slow drift, this algorithm also depends on a parameter drift for drift correction.
-    To get better results, it is recommended to remove extreme standalone outliers before using this technique.
+    Remove extreme standalone outliers before using this technique to get better results.
 
     Attributes:
         data (pd.Series): Time series data.
@@ -25,17 +25,12 @@ class Cusum:
         detect (str): Type of changes to detect.
         predict_ending (bool): Predict end point.
         alpha (float): Smoothing factor for mean data.
-        plot_cusum (bool): Plot results.
         time_alarm (np.array): Detected change points.
         time_alarm_initial (np.array): Start of the changes.
         time_alarm_final (np.array): End of the changes.
         cumulative_positive_sum (np.array): Cumulative sum of positive changes.
         cumulative_negative_sum (np.array): Cumulative sum of negative changes.
 
-    Raises:
-        UserTypeError: If a time series with the wrong index is provided.
-        UserValueError: If an empty time series is passed into the function.
-
     References:
         https://nbviewer.org/github/demotu/detecta/blob/master/docs/detect_cusum.ipynb
     """
@@ -48,20 +43,19 @@ class Cusum:
         detect: Literal["both", "increase", "decrease"] = "both",
         predict_ending: bool = True,
         alpha: float = 0.05,
-        plot_cusum: bool = False,
     ):
-        """Cusum init function
+        """Cusum init function.
 
         Args:
             data: Time series
             threshold: Amplitid threshold.
                 Cumulative changes are compared to this threshold. Defaults to None.
-                When this is exceeded a change is detected and the cumulative sum restarts from 0.
+                When this threshold is exceeded, a change is detected, and the cumulative sum restarts from 0.
                 If the threshold is not provided, it is assigned to 5 * standard_deviation of the data.
             drift: Drift term.
                 Prevents any change in the absence of change. Defaults to None.
                 If fewer false alarms are wanted, try to increase `drift`.
-                If the threshold is not provided, it is assigned to (2 * data_mean - data_mean) / 2.
+                If the threshold is not provided, it is assigned to (2 * data_standard_deviation - data_mean) / 2.
             detect: Type of changes to detect:
                     * "both" for detecting both increasing and decreasing changes in the data (default)
                     * "increase" for detecting increasing changes in the data
@@ -71,12 +65,11 @@ class Cusum:
                 If false, single change points are detected.
             alpha: Smoothing factor.
                 Value between 0 < alpha <= 1. Defaults to 0.05.
-            plot_cusum: Plot results.
-                Plots 2 figures containing the following data (defaults to False):
-                1. Raw data, smoothed data, detected change points, start of the change and end of the change (if predict_ending = True).
-                2. Cumulative sums for increasing and decreasing changes.
-        """
 
+        Raises:
+            UserTypeError: If a time series with the wrong index is provided.
+            UserValueError: If an empty time series is passed into the function.
+        """
         self.data = data
         self._validate_time_series()
 
@@ -86,7 +79,6 @@ class Cusum:
         self.detect = detect
         self.predict_ending = predict_ending
         self.alpha = alpha
-        self.plot_cusum = plot_cusum
 
         # smooth time series used as mean data
         self.mean_data = data.ewm(alpha=alpha).mean()
@@ -99,12 +91,11 @@ class Cusum:
         self.cumulative_negative_sum = np.array([])
 
     def _validate_time_series(self):
-        """Validate time series
+        """Validate time series.
 
         Raises:
             UserValueError: If an empty time series is passed into the function.
             UserValueError: If a time series with the wrong index is provided.
-
         """
         validate_series_is_not_empty(self.data)
         validate_series_has_time_index(self.data)
@@ -113,13 +104,11 @@ class Cusum:
             raise UserValueError("Time series index is not increasing.")
 
     def _detect_changes(self, endings: bool = False):
-        """
-        Detection of change points.
+        """Detection of change points.
 
         Args:
             endings: Detect only the end of the changes previously detected.
                 Defaults to False.
-
         """
         if endings:  # revert the datapoints
             x = self.data.values[::-1]
@@ -185,13 +174,12 @@ class Cusum:
     def _detect_ending(
         self,
     ):
-        """
-        Estimation of when the change ends (offline form)
-
-        """
-
+        """Estimation of when the change ends (offline form)."""
         self._detect_changes(endings=True)
 
+        self._fix_time_alarm_size_errors()
+
+    def _fix_time_alarm_size_errors(self):
         if self.time_alarm_initial.size != self.time_alarm_final.size:
             if self.time_alarm_initial.size < self.time_alarm_final.size:
                 self.time_alarm_final = self.time_alarm_final[
@@ -210,14 +198,12 @@ class Cusum:
             self.time_alarm_final = self.time_alarm_final[~np.append(ind, False)]
 
     def _plot_cusum(self) -> None:
-        """Plot cusum results
+        """Plot cusum results.
 
         Plots 2 figures containing the results of the cusum function:
         1. Raw data, smoothed data, detected change points, start of the change and end of the change (if predict_ending = True).
         2. Cumulative sums for increasing and decreasing changes.
-
         """
-
         try:
             import matplotlib.pyplot as plt
         except ImportError:
@@ -283,7 +269,7 @@ class Cusum:
             plt.show()
 
     def _create_binary_output(self) -> pd.Series:
-        """Binary pd.Series with the detected changes
+        """Binary pd.Series with the detected changes.
 
         Returns:
             pd.Series: Binary time series.
@@ -305,7 +291,7 @@ class Cusum:
         self,
         plot_cusum: bool = False,
     ) -> pd.Series:
-        """Cumulative sum (CUSUM)
+        """Cumulative sum (CUSUM).
 
         This technique calculates the cumulative sum of positive and negative changes (g+t and g−t) in the data (x) and compares them to a threshold.
         When this threshold is exceeded a change is detected (ttalarm) and the cumulative sum restarts from zero.
@@ -323,7 +309,6 @@ class Cusum:
         References:
             https://nbviewer.org/github/demotu/detecta/blob/master/docs/detect_cusum.ipynb
         """
-
         self._detect_changes()
 
         if self.time_alarm_initial.size and self.predict_ending:
@@ -345,14 +330,14 @@ def cusum(
         "cusum_binary_result", "mean_data", "positive_cumulative_sum", "negative_cumulative_sum"
     ] = "cusum_binary_result",
 ) -> pd.Series:
-    """Cumulative sum (CUSUM)
+    """Cumulative sum (CUSUM).
 
     This technique calculates the cumulative sum of positive and negative changes (g+t and g−t) in the data (x) and compares them to a threshold.
-    When this threshold is exceeded a change is detected (ttalarm) and the cumulative sum restarts from zero.
-    To avoid the detection of a change in absence of an actual change or a slow drift, this algorithm also depends on a parameter drift for drift correction.
-    To get better results, it is recommended to remove extreme standalone outliers before using this technique.
+    When this threshold is exceeded, a change is detected (ttalarm), and the cumulative sum restarts from zero.
+    To avoid the detection of a change in absence of an actual change or a slow drift, this algorithm also depends on a parameter `drift` for drift correction.
+    Remove extreme standalone outliers before using this technique to get a better result.
 
-    Typical procedure to use this function:
+    Typical uses of this function:
 
     1. Set the type of series to return to "mean_data" to visualize the smoothed data. Leave the rest of the parameters to their default values.
     2. Adjust the alpha parameter to get the desired smoothing for the data.
@@ -371,8 +356,7 @@ def cusum(
             If fewer false alarms are wanted, try to increase `drift`.
             If the threshold is not provided, it is assigned to (2 * data_standard_deviation - data_mean) / 2.
         detect: Type of changes to detect.
-                Options are:
-
+              Options are:
                 * "both" for detecting both increasing and decreasing changes in the data (default)
                 * "increase" for detecting increasing changes in the data
                 * "decrease" for detecting decreasing changes in the data
@@ -390,6 +374,7 @@ def cusum(
             * "mean_data" returns the smoothed data.
             * "positive_cumulative_sum" returns the positive cumulative sum.
             * "negative_cumulative_sum" returns the negative cumulative sum.
+
     Returns:
         pd.Series: Time series.
             Specified in the return_series_type parameter.
@@ -401,7 +386,6 @@ def cusum(
     References:
         https://nbviewer.org/github/demotu/detecta/blob/master/docs/detect_cusum.ipynb
     """
-
     cusum_detection = Cusum(
         data=data,
         threshold=threshold,
@@ -409,7 +393,6 @@ def cusum(
         detect=detect,
         predict_ending=predict_ending,
         alpha=alpha,
-        plot_cusum=False,
     )
 
     if return_series_type == "mean_data":
