@@ -13,9 +13,9 @@ def drift(
     std_threshold: float = 3,
     detect: str = "both",
 ):
-    """Drift
+    """Drift.
 
-    Detects data drift (deviation) by comparing two rolling averages, short and long interval, of the signal. The
+    This function detects data drift (deviation) by comparing two rolling averages, short and long interval, of the signal. The
     deviation between the short and long term average is considered significant if it is above a given threshold
     multiplied by the rolling standard deviation of the long term average.
 
@@ -26,18 +26,17 @@ def drift(
         short_interval: Short length.
             Length of short term time interval.
         std_threshold: Threshold.
-            Parameter that determines the signal has changed significantly enough to be considered drift. The threshold
+            Parameter that determines if the signal has changed significantly enough to be considered drift. The threshold
             is multiplied by the long term rolling standard deviation to take into account the recent condition of the
             signal.
         detect: Type.
             Parameter to determine if the model should detect significant decreases, increases or both. Options are:
-            "decrease", "increase" or "both". Defaults to "both"
+            "decrease", "increase", or "both". Defaults to "both".
 
     Returns:
       pandas.Series: Boolean time series.
-      Drift = 1, No drift = 0.
+        Drift = 1, No drift = 0.
     """
-
     # Compute long term average and std
     long_average = data.rolling(long_interval).mean()
     long_stds = data.rolling(long_interval).std()
