@@ -9,7 +9,9 @@ from ..validations import validate_series_has_time_index
 
 @check_types
 def resample_timeseries(data: pd.Series) -> pd.Series:
-    """Resamples a timeseries (provided as a pandas Series with datetime index)
+    """Resample timeseries.
+
+    Resamples a timeseries (provided as a pandas Series with datetime index)
     into a equally spaced timeseries with the frequency defined by the smallest
     delta time between each timestamp.
 
@@ -19,7 +21,6 @@ def resample_timeseries(data: pd.Series) -> pd.Series:
     Returns:
         pandas.Series: Resampled Time series
     """
-
     validate_series_has_time_index(data)
     if len(data) < 2:
         raise UserValueError(f"Expected data to be of length >= 2, got length {len(data)}")
