@@ -16,7 +16,7 @@ def total_head(
     den: Union[pd.Series, float],
     align_timesteps: bool = False,
 ) -> pd.Series:
-    r"""Total head
+    r"""Total head.
 
     Head is a measure of the potential of a liquid to reach a certain
     height. The head is essentially a unit of pressure. The total head
@@ -52,31 +52,30 @@ def total_head(
 def percent_BEP_flowrate(
     pump_liquid_flowrate: Union[pd.Series, float], BEP_flowrate: Union[pd.Series, float], align_timesteps: bool = False
 ) -> pd.Series:
-    r"""BEP from flowrate [%]
+    r"""BEP from flowrate [%].
 
-    Centrifugal pumps operate optimally at a specific liquid flowrate which is typically called the Best Efficiency Point (BEP).
-    This function calculates the flowrate relative to BEP as a percentage.
-    i.e. 100% means the current flowrate is at the BEP, 110% means the
-    current flowrate is 10% above BEP. The formula for this equation is:
+    Centrifugal pumps operate optimally at a specific liquid flow rate which is typically called the Best Efficiency Point (BEP).
+    This function calculates the flow rate relative to BEP as a percentage.
+    i.e. 100% means the current flow rate is at the BEP, 110% means the
+    current flow rate is 10% above BEP. The formula for this equation is:
 
     .. math::
-        BEP\:from\:flowrate\:[\%]=\frac{Pump\:liquid\:flowrate}
+        BEP\:from\:flow rate\:[\%]=\frac{Pump\:liquid\:flow rate}
         {BEP}*100
 
     Args:
-        pump_liquid_flowrate: Pump liquid flowrate [:math:`\mathrm{\frac{m^3}{s}}`].
-            The current flowrate of the pump.
+        pump_liquid_flowrate: Pump liquid flow rate [:math:`\mathrm{\frac{m^3}{s}}`].
+            The current flow rate of the pump.
         BEP_flowrate: Best efficiency point [-].
-            The best efficiency flowrate point of the pump.
+            The best efficiency flow rate point of the pump.
         align_timesteps: Auto-align.
             Automatically align time stamp  of input time series. Default is False.
 
     Returns:
         pandas.Series: BEP to current flowrate [%].
-            Percentage of current flowrate to BEP
+            Percentage of current flow rate to BEP
 
     """
-
     pump_liquid_flowrate, BEP_flowrate = auto_align([pump_liquid_flowrate, BEP_flowrate], align_timesteps)
     percent_BEP_Q = pump_liquid_flowrate / BEP_flowrate * 100
 
@@ -90,11 +89,11 @@ def pump_hydraulic_power(
     den: Union[pd.Series, float],
     align_timesteps: bool = False,
 ) -> pd.Series:
-    r"""Pump hydraulic power
+    r"""Pump hydraulic power.
 
     Pump hydraulic power [W] is the amount of energy per unit time
     delivered to the liquid. Pump hydraulic power can be calculated
-    if the pump liquid flowrate :math:`Q_L\:[\frac{m^3}{s}]`, total head across the pump
+    if the pump liquid flow rate :math:`Q_L\:[\frac{m^3}{s}]`, total head across the pump
     :math:`h` [m], and density of the fluid :math:`\rho_L\:[\frac{kg}{m^3}]`.
 
     .. math::
@@ -102,8 +101,8 @@ def pump_hydraulic_power(
 
     Args:
 
-        pump_liquid_flowrate: Pump liquid flowrate [:math:`\mathrm{\frac{m^3}{s}}`].
-            The current flowrate of the pump.
+        pump_liquid_flowrate: Pump liquid flow rate [:math:`\mathrm{\frac{m^3}{s}}`].
+            The current flow rate of the pump.
         total_head: Total head across pump [m].
             Difference in pressure between discharge and suction of pump.
         den: Density of the fluid [:math:`\mathrm{\frac{kg}{m^3}}`].
@@ -131,12 +130,12 @@ def pump_shaft_power(
     eff_intercept: Union[pd.Series, float],
     align_timesteps: bool = False,
 ) -> pd.Series:
-    r"""Pump shaft power
+    r"""Pump shaft power.
 
     Pump shaft power is the input power delivered by the shaft.
     Pump shaft power can be calculated by dividing the pump hydraulic hp
-    by the pump efficiency. Pump efficiency is a function of liquid flowrate :math:`\eta(Q_L)`.
-    The pump efficiency curve as a function of liquid flowrate is assumed to be a 2nd order polynomial.
+    by the pump efficiency. Pump efficiency is a function of liquid flow rate :math:`\eta(Q_L)`.
+    The pump efficiency curve as a function of liquid flow rate is assumed to be a 2nd order polynomial.
     Therefore the input parameters of the curve are coefficients
     to :math:`x^2` and :math:`x` and the :math:`y` intercept of the curve.
 
@@ -147,7 +146,7 @@ def pump_shaft_power(
 
         pump_hydraulic_power: Pump hydraulic power [W].
         pump_liquid_flowrate: Pump liquid flowrate [:math:`\mathrm{\frac{m^3}{h}}`].
-            The current flowrate of the pump.
+            The current flow rate of the pump.
         eff_parameter_1: :math:`x^2` coefficient [-].
             Coefficient of :math:`x^2`.
         eff_parameter_2: :math:`x` coefficient [-].
@@ -181,10 +180,10 @@ def recycle_valve_power_loss(
     den: Union[pd.Series, float],
     align_timestamps: bool = False,
 ) -> pd.Series:
-    r"""Pump recycle valve power loss
+    r"""Pump recycle valve power loss.
 
     This calculation can be used where there is a recirculation line with a recycle valve whose purpose is to maintain a minimum flow through the pump.
-    The calculation does not take into account the difference in pump efficiency at different flow rates. This is acceptable because pumps are usually sized to take into account extra flow due to recirculation.
+    The calculation does not consider the difference in pump efficiency at different flow rates. This is acceptable because pumps are usually sized to account for extra flow due to recirculation.
 
     .. math::
             Power\:loss=9.81Q_{valve}\rho_Lh
