@@ -9,10 +9,10 @@ from indsl.type_check import check_types
 
 @check_types
 def status_flag_filter(data: pd.Series, filter_by: pd.Series, int_to_keep: int = 0, align_timesteps: bool = False):
-    """Status flag filter
+    """Status flag filter.
 
-    Function to filter any given data series by a series with integers denoting different states. A typical example of
-    such a series is typically a series of 0 and 1 where 1 would indicate the presence of an anomaly.
+    This function filters any given data series by a series with integers denoting different states. A typical example of
+    such a series is a series of 0 and 1 where 1 would indicate the presence of an anomaly.
     The status flag filter retrieves all relevant indices and matches these to the data series.
 
     Args:
@@ -21,17 +21,16 @@ def status_flag_filter(data: pd.Series, filter_by: pd.Series, int_to_keep: int =
             Time series values are expected to be integers. If not, values are cast to integer automatically.
         int_to_keep: Value.
             Value to filter by in the boolean filter
-        align_timesteps: Auto-align
-          Automatically align time stamp  of input time series. Default is False.
+        align_timesteps: Auto-align.
+          Automatically align time stamp of input time series. Default is False.
 
     Returns:
         pandas.Series: Filtered time series
 
     Raises:
-        UserRuntimeError: Timeseries returns no data. This could be due to the absence of sufficient data in either `data`
-            or `filter_by` or `filter_by` series contains no values of `int_to_keep`.
+        UserRuntimeError: Time series returns no data. This could be due to insufficient data in either `data`
+            or `filter_by`, or `filter_by` series contains no values of `int_to_keep`.
     """
-
     data, filter_by = auto_align([data, filter_by], align_timesteps)
 
     # Select index to keep
