@@ -11,6 +11,8 @@ from ..type_check import check_types
 
 
 class MethodType(Enum):
+    """Method type."""
+
     ONESTEP = "onestep"
     MULTISTEP = "multistep"
 
@@ -24,9 +26,9 @@ def arma_predictor(
     method: MethodType = MethodType.ONESTEP,
     steps: int = 1,
 ) -> pd.Series:
-    """ARMA predictor
+    """ARMA predictor.
 
-    The ARMA predictor works by fitting constants to a auto regression (AR)  and to a moving average (MA) equation and
+    The ARMA predictor works by fitting constants to an auto regression (AR)  and a moving average (MA) equation and
     extrapolating the results.
 
     Args:
@@ -34,24 +36,22 @@ def arma_predictor(
         ar_order: Number of AR terms.
         ma_order: Number of MA terms.
         train_fraction: Fraction.
-            Fraction of the input data used for training the model
-        method: Method
+            Fraction of the input data used for training the model.
+        method: Method.
             Type of prediction to perform. MULTISTEP involves forecasting
-            several steps ahead of the training dataset while ONESTEP involves incrementally going through the test
-            dataset, appending it to the training dataset by performing a one-step forecast.
+            several steps ahead of the training dataset, while ONESTEP involves incrementally going through the test
+            dataset, and appending it to the training dataset by performing a one-step forecast.
         steps: Steps.
             Number of steps to forecast ahead of the training dataset.
 
     Returns:
         pandas.Series: Prediction
-        Predicted data for the test fraction of the input data (e.g. 1 - train_fraction)
+        Predicted data for the test fraction of the input data (e.g., 1 - train_fraction)
 
     Raises:
-        UserRuntimeError: If an empty time series is passed into the function
-        UserValueError: Incorrect values passed into keyword arguments. ar_order and ma_order should be integers and train_fraction must be float between 0 and 1.
-
+        UserRuntimeError: If an empty time series is passed into the function.
+        UserValueError: Incorrect values passed into keyword arguments. ar_order and ma_order should be integers, and train_fraction must be float between 0 and 1.
     """
-
     # Check length of data
     if len(data) < 1:
         raise UserRuntimeError("No data passed to algorithm.")
@@ -98,7 +98,9 @@ def arma_predictor(
 
 
 def _train_and_return_forecast(ar_order: int, ma_order: int, train_data: pd.Series, steps: int, dt_step_sec: int):
-    """Function to train an ARMA model and return the forecasted value as a Pandas series with a datetime index
+    """Train and return forecast.
+
+    Function to train an ARMA model and return the forecasted value as a Pandas series with a datetime index
 
     Args:
         ar_order: Number of AR terms in the equation
@@ -110,7 +112,6 @@ def _train_and_return_forecast(ar_order: int, ma_order: int, train_data: pd.Seri
     Returns:
         pandas.Series: Forecasted time series of length `steps`
     """
-
     # Fit ARMA model
     model = ARIMA(train_data, order=(ar_order, 0, ma_order))
     fit_model = model.fit()
