@@ -6,8 +6,9 @@ from indsl.versioning import register
 
 @register(version="1.0", deprecated=True, changelog="Intended for CHARTS internal use only")
 def no_op(series: pd.Series):
-    """Identity operator
-    Return the input unmodified as output
+    """Identity operator.
+
+    Return the input unmodified as output.
 
     Args:
         series: input
