@@ -10,7 +10,7 @@ from indsl.type_check import check_types
 
 @check_types
 def productivity_index(p_res: pd.Series, p_bh: pd.Series, Q_gas: pd.Series, align_timesteps: bool = False):
-    """Productivity Index
+    """Productivity Index.
 
     The productivity index or PI is defined as the gas flow rate at the well divided by the difference in pressure
     between the reservoir and bottom hole. If there is no data available for any of the inputs for a specific
@@ -28,9 +28,7 @@ def productivity_index(p_res: pd.Series, p_bh: pd.Series, Q_gas: pd.Series, alig
 
     Raises:
         RuntimeError: If any input time series has no data, then PI can't be computed for any timestamps.
-
     """
-
     p_res, p_bh, Q_gas = auto_align([p_res, p_bh, Q_gas], align_timesteps)
 
     if len(p_res) == 0 or len(p_bh) == 0 or len(Q_gas) == 0:
