@@ -1,5 +1,4 @@
 # Copyright 2021 Cognite AS
-
 import numpy as np
 import pandas as pd
 
@@ -20,7 +19,7 @@ M_AIR = 28.97  # Molar mass of air (Kg/kmol)
 def calculate_gas_density(
     pressure: pd.Series, temperature: pd.Series, sg: pd.Series, align_timesteps: bool = False
 ) -> pd.Series:
-    """Gas density calculator
+    """Gas density calculator.
 
     The gas density is calculated from real gas laws.The psuedo critical tempreature and pressure is
     calculated from specific gravity following `Sutton (1985) <https://doi.org/10.2118/14265-MS>`_. The
@@ -38,12 +37,13 @@ def calculate_gas_density(
            Specific gravity of the gas.
        align_timesteps: Auto-align
           Automatically align time stamp  of input time series. Default is False.
+
     Returns:
        pandas.Series: Gas density [lbm/ft3]
            Estimated gas density in pound-mass per cubic foot (pcf).
+
     Raises:
        RuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
-
     """
     # check specific gravity value
     sg = sg[0]
@@ -90,20 +90,20 @@ def calculate_gas_density(
 
 
 def calculate_critical_prop(sg: float):
-    """Critical properties
+    """Critical properties.
 
     Returns the crtitcal pressure and temperature as a function of specific gravity (Sutton - 1973).
 
     Args:
        sg: Specific gravity
            Specific gravity of the gas.
+
     Returns:
        float: Critical pressure
            Critical pressure in KPa.
        float: Critical temperature
            Critical temperature in Kelvin.
     """
-
     Tc_R = 169.2 + 349.5 * sg - 74 * sg**2
     Tc = CONVERT_R_TO_K * Tc_R  # convert from Rankine to K
     Pc_psi = 756.8 - 131.07 * sg - 3.6 * sg**2
@@ -112,7 +112,7 @@ def calculate_critical_prop(sg: float):
 
 
 def calculate_reduced_prop(pressure_Kpa: pd.Series, temperature_K: pd.Series, Pc: float, Tc: float):
-    """Reduced properties
+    """Reduced properties.
 
     Returns the reduced pressure and temperature from input pressure, temperature, and critical prperties.
 
@@ -139,7 +139,7 @@ def calculate_reduced_prop(pressure_Kpa: pd.Series, temperature_K: pd.Series, Pc
 
 
 def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
-    """Gas Compressibility
+    """Gas Compressibility.
 
     Returns the compressibility factor from reduced pressure and temperature.
     Also deletes points in input temperature and pressure that are out of range.
@@ -153,6 +153,7 @@ def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
     Returns:
        pandas.Series: Compressibility factor
             Non-dimensional series.
+
     Raises:
        UserRuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
     """
