@@ -15,7 +15,7 @@ def calculate_shutin_interval(
     shutin_state_below_threshold: bool = True,
     shutin_threshold: int = None,
 ):
-    """Shut-in interval
+    """Shut-in interval.
 
     The shut-in interval is defined as period when the valve is in closed state. The close state is determined based
     on the calculated manually-given threshold. The threshold is calculated based on the analysis of the valve signal
@@ -39,9 +39,7 @@ def calculate_shutin_interval(
 
     Raises:
         RuntimeError: If threshold cannot be determined in the evaluation window, the user is asked to increase the evaluation period. Recommended period is 30 days.
-
     """
-
     # calculate threshold
     if not shutin_threshold:
         shutin_threshold = calculate_threshold(shut_valve)
@@ -105,7 +103,9 @@ def calculate_shutin_interval(
 
 
 def calculate_threshold(shut_valve: pd.Series):
-    """The valve threshold refers to the threshold between valve open and close states. The threshold is calculated as
+    """Calculate valve threshold.
+
+    The valve threshold refers to the threshold between valve open and close states. The threshold is calculated as
     a mean of two histogram peaks (max values). The histogram should have two peaks indicating two states.
 
     Args:
@@ -117,9 +117,7 @@ def calculate_threshold(shut_valve: pd.Series):
 
     Raises:
         RuntimeError: If threshold cannot be determined in the evaluation window, the user is asked to increase the evaluation period. Recommended period is 30 days.
-
     """
-
     freqs, edges = np.histogram(shut_valve.values, bins=5)
     # get indices of 2 most frequent bins
     freqs_sorted = [el[0] for el in sorted(enumerate(freqs), key=lambda x: x[1])]
