@@ -11,7 +11,7 @@ from ..type_check import check_types
 def calculate_shutin_variable(
     variable_signal: pd.Series, shutin_signal: pd.Series, hrs_after_shutin: float
 ) -> pd.Series:
-    """Shut-in variable calculator
+    """Shut-in variable calculator.
 
     Shut-in variable calculator is a function to compute the variable of interest at specific times after the shut-in
     onset. Typically, variables of interest are pressure and temperature. The function is the dependency of the shut-in
@@ -31,7 +31,6 @@ def calculate_shutin_variable(
     Returns:
         pandas.Series: Output.
         Signal of interest at specific time after shut-in onset.
-
     """
     if shutin_signal.empty or variable_signal.empty:
         return pd.Series(dtype=np.float64, index=pd.DatetimeIndex([]))
