@@ -21,7 +21,7 @@ def calculate_well_prod_status(
     threshold_choke: float = 5,
     align_timesteps: bool = False,
 ) -> pd.Series:
-    """Check if the well is producing
+    """Check if the well is producing.
 
     Determine if the well is producing. In order for this to be the case, the following has to happen:
     * All Master, Wing and Choke data have to come from the same well.
@@ -54,7 +54,6 @@ def calculate_well_prod_status(
         pandas.Series: Well Status
             Well production status (1 means open, 0 means closed).
     """
-
     master_valve, wing_valve, choke_valve = auto_align([master_valve, wing_valve, choke_valve], align_timesteps)
 
     valves = [master_valve, wing_valve, choke_valve]
