@@ -8,18 +8,17 @@ import pandas as pd
 from .reindex import reindex_many
 
 
-def is_timeseries(data):
+def _is_timeseries(data):
     return isinstance(data, pd.Series) and np.issubdtype(data.index, np.datetime64)
 
 
 def auto_reindex(data: List[Union[Iterable, Number, pd.Series]], enabled: bool = True):
-    """Automatically re-reindex input time series"""
-
+    """Automatically re-reindex input time series."""
     if not enabled:
         return data
 
     # Extract sub-list with time-series - only these entries will be reindexed
-    id_ts_map = {i: d for i, d in enumerate(data) if is_timeseries(d)}
+    id_ts_map = {i: d for i, d in enumerate(data) if _is_timeseries(d)}
 
     # Reindex
     reindexed_ts = reindex_many(list(id_ts_map.values()), bounded=True)
@@ -32,4 +31,5 @@ def auto_reindex(data: List[Union[Iterable, Number, pd.Series]], enabled: bool =
 
 
 def auto_align(data: List[Union[Iterable, Number, pd.Series]], enabled: bool = True):
+    """Automatically re-reindex input time series."""
     return auto_reindex(data, enabled=enabled)
