@@ -12,12 +12,12 @@ from ..exceptions import UserTypeError, UserValueError
 from ..type_check import check_types
 
 
-class Kind(Enum):
+class Kind(Enum):  # noqa: D101
     POINTWISE = "pointwise"
     AVERAGE = "average"
 
 
-class Method(Enum):
+class Method(Enum):  # noqa: D101
     ZERO_PREVIOUS = "zero order spline interpolation (forward filling)"
     ZERO_NEXT = "zero order spline interpolation (backward filling)"
     LINEAR = "first order spline interpolation"
@@ -25,6 +25,11 @@ class Method(Enum):
     CUBIC = "third order plines interpolation"
 
     def to_interpd1_arg(self):
+        """Get method used for scipy.interpolation.
+
+        Returns:
+            str: Interpolation method.
+        """
         if self is Method.ZERO_PREVIOUS:
             return "zero"
         if self is Method.ZERO_NEXT:
@@ -45,7 +50,7 @@ def reindex(
     kind: Kind = Kind.POINTWISE,
     bounded: bool = False,
 ) -> List[pd.Series]:
-    """Reindex
+    """Reindex.
 
     This method offers data reindexing onto a common index and fills missing data points.
     If bounded is false, the common index is the union of the the input time-series indices.
@@ -101,7 +106,22 @@ def reindex_many(
     kind: Kind = Kind.POINTWISE,
     bounded: bool = False,
 ) -> List[pd.Series]:
+    """Re-indexes list.
 
+    Args:
+        data: List[pd.Series]
+        method: Method, defaults to Method.LINEAR
+        kind: Kind, defaults to Kind.POINTWISE
+        bounded: bool, defaults to False
+
+    Raises:
+        UserTypeError: Only DateTimeIndex index supported.
+        UserValueError: One of the time series has less than two values.
+        UserTypeError:  The re-indexed time series is empty.
+
+    Returns:
+        List[pd.Series]: re-indexed list
+    """
     # Nothing to do if data contains less than 2 series
     if len(data) < 2:
         return data
