@@ -3,7 +3,7 @@ import operator as op
 import warnings
 
 from enum import Enum
-from typing import Literal
+from typing import Literal, Optional
 
 import pandas as pd
 
@@ -20,14 +20,14 @@ from ..validations import validate_series_has_time_index
 def resample(
     data: pd.Series,
     method: Literal["fourier", "polyphase", "interpolate", "min", "max", "sum", "count", "mean"] = "fourier",
-    granularity_current: str = None,
+    granularity_current: Optional[str] = None,
     granularity_next: str = "1s",
-    num: int = None,
-    downsampling_factor: int = None,
-    interpolate_resolution: str = None,
-    ffill_resolution: str = None,
+    num: Optional[int] = None,
+    downsampling_factor: Optional[int] = None,
+    interpolate_resolution: Optional[str] = None,
+    ffill_resolution: Optional[str] = None,
 ) -> pd.Series:
-    """Resample
+    """Resample.
 
     This method offers a robust filling of missing data points and data resampling a given sampling frequency. Multiple
     data resampling options are available:
@@ -87,12 +87,6 @@ def resample(
     if not granularity_next and (not num or num <= 0):
         raise UserTypeError("Either num or granularity_next has to be set.")
 
-    if method not in ("fourier", "polyphase", "interpolate", "min", "min", "max", "sum", "count"):
-        raise UserTypeError(
-            f"Method has to be in 'fourier', 'polyphase', 'interpolate', 'min', 'max', 'sum', 'count'. Method used was {method}"
-        )
-        return data
-
     validate_series_has_time_index(data)
     if len(data) == 0:
         raise UserValueError(f"Expected data to be of length > 0, got length {len(data)}")
@@ -146,7 +140,7 @@ def resample(
     return series
 
 
-class AggregateEnum(Enum):
+class AggregateEnum(Enum):  # noqa
     MEAN = "mean"
     INTERPOLATION = "interpolation"
     STEP_INTERPOLATION = "stepInterpolation"
@@ -160,7 +154,7 @@ class AggregateEnum(Enum):
 def resample_to_granularity(
     series: pd.Series, granularity: str = "1h", aggregate: AggregateEnum = AggregateEnum.MEAN
 ) -> pd.Series:
-    """Resample to granularity
+    """Resample to granularity.
 
     Resample time series to a given fixed granularity (time delta) and aggregation type
     (`read more about aggregation <https://docs.cognite.com/dev/concepts/aggregation/>`_)
