@@ -1,4 +1,3 @@
-import numbers
 import warnings
 
 from typing import List, Literal, Optional
@@ -8,7 +7,7 @@ import pandas as pd
 
 from indsl.ts_utils.utility_functions import TimeUnits
 
-from ..exceptions import UserTypeError, UserValueError
+from ..exceptions import UserValueError
 from ..type_check import check_types
 from ..validations import validate_series_has_time_index
 
@@ -21,7 +20,7 @@ def line(
     slope: float = 0,
     intercept: float = 0,
 ) -> pd.Series:
-    """Line
+    """Line.
 
     Generate a synthetic time series using the line equation. If no end and/or start dates are given, the default
     signal duration is set to 1 day. If no dates are provided, the end date is set to the current date and time.
@@ -61,10 +60,8 @@ def line(
 
 
 @check_types
-def const_value(
-    value: float = 0,
-) -> pd.Series:
-    """Constant value
+def const_value(value: float = 0, timedelta: pd.Timedelta = pd.Timedelta("1 W")) -> pd.Series:
+    """Constant value.
 
     This function generates a horizontal line. The assumptions when generating the horizontal line
     is that the start date is set as "1970-01-01", the end date is set as "now" and the sampling is "1 week".
@@ -73,15 +70,26 @@ def const_value(
 
     Args:
         value: Value.
-                value. Defaults to 0.
+            value. Defaults to 0.
+        timedelta: Granularity.
+            Sampling frequency as a time delta, value and time unit. Defaults to one week ('1 W'). Valid time units are:
+
+                * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
+                * ‘days’ or ‘day’
+                * ‘hours’, ‘hour’, ‘hr’, or ‘h’
+                * ‘minutes’, ‘minute’, ‘min’, or ‘m’
+                * ‘seconds’, ‘second’, or ‘sec’
+                * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
+                * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
+                * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
+
     Returns:
         pandas.Series: Time series.
             Synthetic time series for a line
 
     """
-    sample_freq = pd.Timedelta(weeks=1)
     slope = 0
-    idx = _make_index(start="1970-01-01", end="now", freq=sample_freq)
+    idx = _make_index(start="1970-01-01", end="now", freq=timedelta)
     if len(idx) > 1e8:
         idx = idx[len(idx) - 100000 :]
 
@@ -98,7 +106,7 @@ def sine_wave(
     wave_amplitude: float = 1,
     wave_phase: float = 0,
 ) -> pd.Series:
-    """Sine wave
+    """Sine wave.
 
     Generate a time series for a `sine wave <https://en.wikipedia.org/wiki/Sine_wave>`_ with a given wave period,
     amplitude, phase and mean value. If no end and/or start dates are given, the default signal duration is set to
@@ -166,7 +174,8 @@ def sine_wave(
 
 
 def _get_sample_frequency(sample_freq: float, unit: TimeUnits):
-    """
+    """Get sample frequency.
+
     Helper method to convert the frequency magnitude and units into a string that is then used by other function
     to generate DatetimeIndex data
     Args:
@@ -192,7 +201,7 @@ def _get_sample_frequency(sample_freq: float, unit: TimeUnits):
 
 @check_types
 def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
-    """Perturb timestamp
+    """Perturb timestamp.
 
     Perturb the date-time index (timestamp) of the original time series using a normal (Gaussian) distribution
     with a mean of zero and a given standard deviation (magnitude) in seconds.
@@ -215,11 +224,6 @@ def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
     validate_series_has_time_index(data)
 
     time = _time_array(data.index)
-    if not isinstance(magnitude, numbers.Real):
-        raise UserTypeError(
-            f"Magnitude is supposed to be a float representing the time scale perturbation magnitude "
-            f"in seconds. The value passed was Magnitude = {magnitude}"
-        )
 
     rng = np.random.default_rng(1975)
     time_perturbations = rng.normal(0, magnitude, len(time))
@@ -241,7 +245,7 @@ def insert_data_gaps(
     data_buffer: int = 5,
     method: Literal["Random", "Single", "Multiple"] = "Random",
 ) -> pd.Series:
-    """Insert data gaps
+    """Insert data gaps.
 
     Method to synthetically remove data, i.e. generate data gaps in a time series. The amount of data points removed
     is defined by the given 'fraction' relative to the original time series.
@@ -282,7 +286,6 @@ def insert_data_gaps(
         UserTypeError: fraction is not a number
         UserTypeError: fraction is not a number
 
-
     """
     original_length = len(data)
     rng = np.random.default_rng(1975)
@@ -334,17 +337,18 @@ def insert_data_gaps(
 
 
 def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int = 5):
-    """
-    Internal method to handle overlapping gaps. The method calculates the number of available space to rearrange
-    gaps in such a way that they do not overlap. Then traverses the ranges according to their location from left to
-    right (time 0 to end) and estimates how many steps ranges to the left or right must be moved to comply with gap
-    generation conditions:
+    """Handle overlapping gaps.
 
-        * The first and last 5 data points of the time series must be preserved
-        * A minimum number of data points, defined by `buffer` must exist between adjacent gaps
-        * The number of available data point to move ranges around can not exceed the number of overlaps
-    """
+    Internal method to handle overlapping gaps. The method calculates the
+    number of available space to rearrange gaps in such a way that they do not
+    overlap. Then traverses the ranges according to their location from left to
+    right (time 0 to end) and estimates how many steps ranges to the left or
+    right must be moved to comply with gap generation conditions:
 
+    * The first and last 5 data points of the time series must be preserved
+    * A minimum number of data points, defined by `buffer` must exist between adjacent gaps
+    * The number of available data point to move ranges around can not exceed the number of overlaps
+    """
     new_ranges = np.copy(gap_ranges)
     if len(gap_ranges) < 3:
         raise UserValueError(f"At least three ranges are required. Value provided was {gap_ranges}")
@@ -355,13 +359,13 @@ def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int
         )
 
     def _calculate_overlaps():
-        """
+        """Calculate overlaps.
+
         Calculates the overlap between adjacent intervals as positive numbers and the space between intervals
         as a positive number, enforcing a minimum distance between intervals given by a buffer of data points.
         The overlap is always calculated looking to the left of an interval. For example, if two intervals
         with index locations int1=[10, 15] and int2=[16, 20] an overlap of 5 is assigned to it. If they were
         int1=[10, 15] and int2=[22, 25], an overlap of -1 (or free space of 1 index) would be assigned.
-        The
         """
         lin_ranges = np.reshape(new_ranges, (1, np.size(new_ranges))).squeeze()
         lin_ranges = np.insert(lin_ranges, 0, -1)
@@ -443,7 +447,7 @@ def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int
 
 
 def _time_array(index: pd.DatetimeIndex) -> np.array:
-    """Get time array
+    """Get time array.
 
     Convert a pandas DatetimeIndex to a time array in seconds, where t=0 is the start date of the index.
 
@@ -464,14 +468,12 @@ def _make_index(
     end: Optional[pd.Timestamp] = None,
     freq: Optional[pd.Timedelta] = pd.Timedelta(1, "m"),
 ) -> pd.DatetimeIndex:
-    """Make datetime index
+    """Make datetime index.
 
     Method to generate a datetime index with a uniform time stamp. The time step default is 1 minute and
     a date range (total duration) defaults to 1 day, unless different parameter are provided (start, end, and sample
     frequency).
 
-    Returns:
-
     Args:
         start: Start date-time
         end: End date-time
@@ -509,14 +511,8 @@ def _make_index(
         freq = pd.Timedelta(1, "m")
         warnings.warn("Can't recognize the sample frequency, setting it to the '1 m' default.")
 
-    try:
-        index = pd.date_range(start=start_date, end=end_date, freq=freq)
-        return index
-    except UserValueError:
-        print(
-            f"One of the input values is wrong or not supported: "
-            f"\n start = {start_date} \n end = {end_date} \n freq = {freq}"
-        )
+    index = pd.date_range(start=start_date, end=end_date, freq=freq)
+    return index
 
 
 def _random_list_of_integers_that_gives_exact_sum(list_length: int, sum_output: int) -> list:
