@@ -9,7 +9,7 @@ def white_noise(
     snr_db: float = 30,
     seed: Optional[int] = None,
 ) -> pd.Series:
-    """Add white noise
+    """Add white noise.
 
     Adds white noise to the original data using a given signal-to-noise ratio (SNR).
 
@@ -28,7 +28,6 @@ def white_noise(
         pandas.Series: Output
             Original data plus white noise.
     """
-
     data_power = data.var()
     # Linear SNR
     snr = 10.0 ** (snr_db / 10.0)
