@@ -7,7 +7,7 @@ from ..type_check import check_types
 
 @check_types
 def univariate_polynomial(signal: pd.Series, coefficients: List[float] = [0.0, 1.0]) -> pd.Series:
-    """Univariate polynomial
+    """Univariate polynomial.
 
     Creates a univariate polynomial :math:`y`, of degree :math:`n`, from the time series :math:`x`, and a list of
     coefficients :math:`a_{n}`:
@@ -24,9 +24,7 @@ def univariate_polynomial(signal: pd.Series, coefficients: List[float] = [0.0, 1
 
     Returns:
         pandas.Series: Output
-
     """
-
     poly = pd.Series(0, index=signal.index)
     n = 0
     for a in coefficients:
