@@ -6,11 +6,12 @@ import pandas as pd
 
 from ..exceptions import UserValueError
 from ..type_check import check_types
+from ..validations import validate_series_has_time_index, validate_series_is_not_empty
 
 
 @check_types
 def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: float = 0.75):
-    """Arnaud Legoux moving average
+    """Arnaud Legoux moving average.
 
     Moving average typically used in the financial industry which aims to strike a good balance between smoothness
     and responsivness (i.e. capture a general smoothed trend without allowing for significant lag). It can be
@@ -27,14 +28,22 @@ def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: flo
             Parameter that controls the magnitude of the weights for each past observation within the window.
             Defaults to 0.75.
 
+    Raises:
+        UserValueError: Time series is empty.
+        UserValueError: Data has to be a time series.
+        UserValueError: Not enough data to perform calculation.
+
     Returns:
         pandas.Series: Smoothed data.
     """
     # TODO : Refactor to accept TIME window instead of number of data points
 
+    validate_series_is_not_empty(data)
+    validate_series_has_time_index(data)
+
     # Check data
     if len(data) <= window:
-        raise RuntimeError(f"Not enough data to perform calculation. Expected {window} but got {len(data)}")
+        raise UserValueError(f"Not enough data to perform calculation. Expected {window} but got {len(data)}")
 
     # Check inputs
     if window == sigma == 0:
