@@ -9,7 +9,7 @@ from ..validations import validate_series_is_not_empty
 
 @check_types
 def arma(data: pd.Series, ar_order: int = 2, ma_order: int = 2):
-    """Autoregressive moving average
+    """Autoregressive moving average.
 
     The autoregressive moving average (ARMA) is a popular model used in forecasting. It uses an autoregression (AR)
     analysis characterize the effect of past values on current values and a moving average to quantify the effect of the
@@ -26,7 +26,6 @@ def arma(data: pd.Series, ar_order: int = 2, ma_order: int = 2):
     Returns:
         pandas.Series: Smoothed data.
     """
-
     # TODO: Refactor to accepet time window
 
     validate_series_is_not_empty(data)
