@@ -16,7 +16,7 @@ def lwma(
     resample: bool = False,
     resample_window: str = "60min",
 ) -> pd.Series:
-    """Linear weighted moving average
+    """Linear weighted moving average.
 
     The linear weighted moving average gives more weight to the more recent observations and gradually less to the older
     ones.
@@ -28,7 +28,8 @@ def lwma(
             If the user gives a number without unit (such as '60'), it will be considered as the number of minutes.
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
         min_periods: Minimum samples.
-            Minimum number of observations in the time window required to estimate a value (otherwise result is NA). Defaults to 1.
+            Minimum number of observations in the time window required to estimate a value (otherwise result is NA).
+            Defaults to 1.
         resample: Resample.
             Resamples the calculated linear weighted moving average series. Defaults to False
         resample_window: Resampling window.
