@@ -11,7 +11,7 @@ from ..type_check import check_types
 
 @check_types
 def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Series:
-    """Saviztky-Golay
+    """Saviztky-Golay.
 
     Use this filter for smoothing data, without distorting the data tendency. The method is independent of
     the sampling frequency, hence simple and robust to apply on data with non-uniform sampling. If working with
@@ -37,7 +37,6 @@ def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Ser
         UserValueError: The window length must be a positive odd integer
         UserValueError: The window length must be less than or equal to the number of data points in your time series
         UserValueError: The polynomial order must be less than the window length
-
     """
     if window_length is None:
         # window_length calculation
