@@ -7,7 +7,7 @@ from indsl.type_check import check_types
 
 @check_types
 def sma(data: pd.Series, time_window: str = "60min", min_periods: int = 1) -> pd.Series:
-    """Simple moving average
+    """Simple moving average.
 
     Plain simple average that computes the sum of the values of the observations in a time_window divided by the number of observations in the time_window.
     SMA time series are much less noisy than the original time series. However, SMA time series lag the original time series, which means that changes in the trend are only seen with a delay (lag) of time_window/2.
