@@ -5,7 +5,7 @@ from ..exceptions import UserTypeError
 
 
 def bands(data: pd.Series, period: str = "1h", K: float = 2.0, as_json: bool = True):
-    """Confidence bands
+    """Confidence bands.
 
     Confidence bands, also known as Bollinger Bands, are a statistical characterization of a time series fluctuations.
     The confidence bands display a graphical envelope (upper and lower bands) given by the deviation (expressed by the
