@@ -16,7 +16,8 @@ from ..exceptions import UserValueError
 
 @check_types
 def add(a, b, align_timesteps: bool = False):
-    """Add
+    """Add.
+
     Add any two time series or numbers.
 
     Args:
@@ -34,7 +35,8 @@ def add(a, b, align_timesteps: bool = False):
 
 @check_types
 def sub(a, b, align_timesteps: bool = False):
-    """Subtraction
+    """Subtraction.
+
     The difference between two time series or numbers.
 
     Args:
@@ -52,7 +54,8 @@ def sub(a, b, align_timesteps: bool = False):
 
 @check_types
 def mul(a, b, align_timesteps: bool = False):
-    """Multiplication
+    """Multiplication.
+
     Multiply two time series or numbers.
 
     Args:
@@ -70,9 +73,11 @@ def mul(a, b, align_timesteps: bool = False):
 
 @check_types
 def div(a, b, align_timesteps: bool = False):
-    """Division
-    Divide two time series or numbers. If the time series in the denominator contains zeros,
-    all instances are dropped from the final result.
+    """Division.
+
+    Divide two time series or numbers. If the time series in the
+    denominator contains zeros, all instances are dropped from the final
+    result.
 
     Args:
         a: Numerator
@@ -83,7 +88,6 @@ def div(a, b, align_timesteps: bool = False):
     Returns:
         pandas.Series: Time series.
     """
-
     a, b = auto_align([a, b], align_timesteps)
 
     if type(b) is pd.Series:
@@ -101,7 +105,8 @@ def div(a, b, align_timesteps: bool = False):
 
 @check_types
 def power(a, b, align_timesteps: bool = False):
-    """Power
+    """Power.
+
     Power of time series or numbers.
 
     Args:
@@ -118,8 +123,9 @@ def power(a, b, align_timesteps: bool = False):
 
 
 def inv(x):
-    """Inverse
-    Element-wise inverse of time series or numbers
+    """Inverse.
+
+    Element-wise inverse of time series or numbers.
 
     Args:
         x: time series or numbers
@@ -131,8 +137,9 @@ def inv(x):
 
 
 def sqrt(x):
-    """Square root
-    Square root of time series or numbers
+    """Square root.
+
+    Square root of time series or numbers.
 
     Args:
         x: time series or numbers
@@ -144,8 +151,9 @@ def sqrt(x):
 
 
 def neg(x):
-    """Negation
-    Negation of time series or numbers
+    """Negation.
+
+    Negation of time series or numbers.
 
     Args:
         x: time series or numbers
@@ -157,8 +165,9 @@ def neg(x):
 
 
 def absolute(x):
-    """Absolute value
-    Absolute value of time series or numbers
+    """Absolute value.
+
+    Absolute value of time series or numbers.
 
     Args:
         x: time series or numbers
@@ -171,8 +180,9 @@ def absolute(x):
 
 @check_types
 def mod(a, b, align_timesteps: bool = False):
-    """Modulo
-    Modulo of time series or numbers
+    """Modulo.
+
+    Modulo of time series or numbers.
 
     Args:
         a: dividend time series or number
@@ -189,8 +199,9 @@ def mod(a, b, align_timesteps: bool = False):
 
 @check_types
 def arithmetic_mean(a, b, align_timesteps: bool = False):
-    """Arithmetic mean
-    Mean of two time series or numbers
+    """Arithmetic mean.
+
+    Mean of two time series or numbers.
 
     Args:
         a: Time series or number
@@ -206,8 +217,9 @@ def arithmetic_mean(a, b, align_timesteps: bool = False):
 
 @check_types
 def arithmetic_mean_many(data: List[Union[pd.Series, float]], align_timesteps: bool = False) -> Union[pd.Series, float]:
-    """Arithmetic mean many
-    Mean of multiple time series
+    """Arithmetic mean many.
+
+    Mean of multiple time series.
 
     Args:
         data: List of time series
