@@ -19,11 +19,13 @@ _unit_in_ms = {**_unit_in_ms_without_week, "w": 604800000}
 
 
 def datetime_to_ms(dt):
+    """Convert datetime to timestamp in milliseconds."""
     epoch = datetime.utcfromtimestamp(0)
     return int((dt - epoch).total_seconds() * 1000.0)
 
 
 def time_string_to_ms(pattern, string, unit_in_ms):
+    """Converts time from string to milliseconds representation."""
     pattern = pattern.format("|".join(unit_in_ms))
     res = re.fullmatch(pattern, string)
     if res:
@@ -34,6 +36,7 @@ def time_string_to_ms(pattern, string, unit_in_ms):
 
 
 def granularity_to_ms(granularity: str) -> int:
+    """Converts granularity from string to milliseconds representation."""
     ms = time_string_to_ms(r"(\d+)({})", granularity, _unit_in_ms_without_week)
     if ms is None:
         raise UserValueError(
@@ -45,7 +48,7 @@ def granularity_to_ms(granularity: str) -> int:
 
 
 def time_ago_to_ms(time_ago_string: str) -> int:
-    """Returns millisecond representation of time-ago string"""
+    """Returns millisecond representation of time-ago string."""
     if time_ago_string == "now":
         return 0
     ms = time_string_to_ms(r"(\d+)({})-ago", time_ago_string, _unit_in_ms)
@@ -73,7 +76,8 @@ def get_fixed_freq(start_time, end_time, granularity):
 
 
 def above_below(series: pd.Series, upper_limit: float, lower_limit: float):
-    """Above/below
+    """Above/below.
+
     Count the number of points above/below upper_limit/lower_limit.
 
     Args:
@@ -124,6 +128,7 @@ def num_vals_in_boxes(series: pd.Series, num_boxes: int):
 
 def functional_mean(function: Callable, x_vals: List) -> np.ndarray:
     """Convenience method to calculate the mean of a function inbetween each x value.
+
     The last point is the function called at the last x value. This is required for the
     input and output lists to have the same lengths.
 
@@ -137,7 +142,6 @@ def functional_mean(function: Callable, x_vals: List) -> np.ndarray:
     Returns:
         numpy.ndarray: Array with the calculated values.
     """
-
     # Catch empty input
     if len(x_vals) == 0:
         raise UserValueError("No data in the input timeseries.")
@@ -170,12 +174,16 @@ def is_na_all(data: Union[pd.DataFrame, pd.Series]) -> bool:
 
 
 def gaps_detector(timestamps: np.ndarray, threshold: int = 86400) -> np.ndarray:
-    """Detect gaps bigger than a threshold in time series
-    Taken from: https://github.com/cognitedata/data-quality-functions/blob/master/functions/completeness/function/completeness.py
+    """Detect gaps bigger than a threshold in time series.
+
+    Taken from:
+    https://github.com/cognitedata/data-quality-
+    functions/blob/master/functions/completeness/function/completeness.py.
 
     Args:
         timestamps: Time array_like.
         threshold: Threshold for gaps. Defaults to 86400 seconds, i.e one full day in epoch time.
+
     Returns:
         numpy.ndarray: 2D array of begin and end time of gaps in seconds epoch time.
     """
@@ -190,9 +198,11 @@ def gaps_detector(timestamps: np.ndarray, threshold: int = 86400) -> np.ndarray:
 
 def check_uniform(data: pd.DataFrame, unit: str = "ns") -> bool:
     """Convenience method to verify input time series is uniform.
+
     Args:
         data: Time series to check. Object must have a datetime-like index.
         unit: Time unit of uniformity check. Follows Numpy DateTime Units convention. Defaults to "ns".
+
     Returns:
         bool: True if input timeseries is uniform, False if not uniform.
     """
@@ -205,11 +215,15 @@ def check_uniform(data: pd.DataFrame, unit: str = "ns") -> bool:
 
 
 def make_uniform(data: pd.DataFrame, resolution: str = "1s", interpolation: str = None) -> pd.DataFrame:
-    """Convenience method to make an input time series dataframe uniform per specified temporal resolution.
+    """Make timeseries uniform.
+
+    Convenience method to make an input time series dataframe uniform per specified temporal resolution.
     Object must have a datetime-like index.
+
     Args:
         resolution: Temporal resolution of uniform time series. Follows Pandas DateTime convention. Defaults to "1s".
         interpolation: Method for optional interpolation. Follows pandas Resampler.interpolate. Defaults to None.
+
     Returns:
         pandas.DataFrame: Uniform Timeseries DataFrame.
     """
@@ -275,7 +289,7 @@ def fill_gaps(
     interpolate_resolution: str = None,
     method: str = "ffill",
 ) -> pd.Series:
-    """Mask nan/fill gaps bases on the time size of missing data
+    """Mask nan/fill gaps bases on the time size of missing data.
 
     Args:
         data: Input time series. Must be uniform.
@@ -283,8 +297,10 @@ def fill_gaps(
         ffill_resolution: Gaps smaller than this will be filled with method. Defaults to None.
         interpolate_resolution: Gaps smaller than this will be interpolated, larger than this will be filled by noise. Defaults to None.
         method: Method used to fill nan. Defaults to 'ffill', but ‘backfill’, ‘bfill’ and ‘pad’ can also be used.
+
     Returns:
         pandas.DataFrame or pd.Series: Uniform, time series without nan values.
+
     Raises:
         UserRuntimeError: The input time series is not uniform
         UserValueError: Unable to convert granularity to time resolution
