@@ -1,7 +1,7 @@
 # Copyright 2021 Cognite AS
 
 from datetime import datetime, timedelta
-from typing import List, Literal, Optional, Tuple
+from typing import List, Literal, Optional, Tuple, Union
 
 import numpy as np
 import pandas as pd
@@ -20,8 +20,9 @@ TimeUnits = Literal["ns", "us", "ms", "s", "m", "h", "D", "W"]
 # Rounding and utility functions
 @check_types
 def round(x, decimals: int):
-    """Round
-    Rounds a time series to a given number of decimals
+    """Round.
+
+    Rounds a time series to a given number of decimals.
 
     Args:
         x: time series
@@ -29,13 +30,16 @@ def round(x, decimals: int):
 
     Returns:
         pd.Series: time series
+
     """
     return np.round_(x, decimals=decimals)
 
 
 def floor(x):
-    """Round down
-    Rounds a time series down to the nearest integer smaller than or equal to the current value
+    """Round down.
+
+    Rounds a time series down to the nearest integer smaller than
+    or equal to the current value.
 
     Args:
         x: time series
@@ -47,8 +51,10 @@ def floor(x):
 
 
 def ceil(x):
-    """Round up
-    Rounds a time series up to the nearest integer greater than or equal to the current value
+    """Round up.
+
+    Rounds a time series up to the nearest integer greater than or
+    equal to the current value.
 
     Args:
         x: time series
@@ -60,8 +66,9 @@ def ceil(x):
 
 
 def sign(x):
-    """Sign
-    Element-wise indication of the sign of a time series
+    """Sign.
+
+    Element-wise indication of the sign of a time series.
 
     Args:
         x: time series
@@ -75,8 +82,10 @@ def sign(x):
 # Clipping functions
 @check_types
 def clip(x, low: float = -np.inf, high: float = np.inf):
-    """Clip(low, high)
-    Given an interval, values of the time series outside the interval are clipped to the interval edges.
+    """Clip(low, high).
+
+    Given an interval, values of the time series outside the
+    interval are clipped to the interval edges.
 
     Args:
         x (pd.Series): time series
@@ -93,8 +102,10 @@ def clip(x, low: float = -np.inf, high: float = np.inf):
 
 @check_types
 def maximum(x1, x2, align_timesteps: bool = False):
-    """Element-wise maximum
-    Computes the maximum value of two timeseries or numbers
+    """Element-wise maximum.
+
+    Computes the maximum value of two timeseries or
+    numbers.
 
     Args:
         x1: First time series or number
@@ -111,8 +122,9 @@ def maximum(x1, x2, align_timesteps: bool = False):
 
 @check_types
 def minimum(x1, x2, align_timesteps: bool = False):
-    """Element-wise minimum
-    Computes the minimum value of two timeseries
+    """Element-wise minimum.
+
+    Computes the minimum value of two timeseries.
 
     Args:
         x1: First time series or number
@@ -129,7 +141,8 @@ def minimum(x1, x2, align_timesteps: bool = False):
 
 @check_types
 def union(series1: pd.Series, series2: pd.Series) -> pd.Series:
-    """Union
+    """Union.
+
     Takes the union of two time series. If a time stamp
     occurs in both series, the value of the first time series is used.
 
@@ -143,14 +156,14 @@ def union(series1: pd.Series, series2: pd.Series) -> pd.Series:
     Raises:
         UserTypeError: series1 or series2 is not a time series
     """
-
     out = pd.concat([series1, series2]).sort_index()
     return out[~out.index.duplicated(keep="first")]
 
 
 @check_types
 def bin_map(x1, x2, align_timesteps: bool = False):
-    """Element-wise greater-than
+    """Element-wise greater-than.
+
     Maps to a binary array by checking if one timeseries is greater than another
 
     Args:
@@ -168,7 +181,8 @@ def bin_map(x1, x2, align_timesteps: bool = False):
 
 @check_types
 def set_timestamps(timestamp_series: pd.Series, value_series: pd.Series, unit: TimeUnits = "ms") -> pd.Series:
-    """Set index of time series
+    """Set index of time series.
+
     Sets the time series values to the Unix timestamps.
     The timestamps follow the Unix convention (Number of seconds
     starting from January 1st, 1970). Both input time series
@@ -198,7 +212,7 @@ def set_timestamps(timestamp_series: pd.Series, value_series: pd.Series, unit: T
 
 @check_types
 def get_timestamps(series: pd.Series, unit: TimeUnits = "ms") -> pd.Series:
-    """Get index of time series
+    """Get index of time series.
 
     Get timestamps of the time series as values.
     The timestamps follow the Unix convention (Number of seconds
@@ -227,7 +241,7 @@ def get_timestamps(series: pd.Series, unit: TimeUnits = "ms") -> pd.Series:
 
 @check_types
 def time_shift(series: pd.Series, n_units: float = 0, unit: TimeUnits = "ms") -> pd.Series:
-    """Shift time series
+    """Shift time series.
 
     Shift time series by a time period
 
@@ -254,9 +268,11 @@ def time_shift(series: pd.Series, n_units: float = 0, unit: TimeUnits = "ms") ->
 
 @check_types
 def replace(series: pd.Series, to_replace: Optional[List[float]] = None, value: Optional[float] = 0.0):
-    """Replace
-    Replace values in a time series. The values to replace should be a semicolon-separated list.
-    Undefined and infinity values can be replaced by using nan, inf and -inf (e.g. 1.0, 5, inf, -inf, 20, nan).
+    """Replace.
+
+    Replace values in a time series. The values to replace should be
+    a semicolon-separated list. Undefined and infinity values can be replaced
+    by using nan, inf and -inf (e.g. 1.0, 5, inf, -inf, 20, nan).
 
     Args:
         series: Time series
@@ -282,10 +298,11 @@ def replace(series: pd.Series, to_replace: Optional[List[float]] = None, value:
 
 @check_types
 def remove(series: pd.Series, to_remove: Optional[List[float]] = None):
-    """Remove
-    Remove values in a time series. The values to remove should be a semicolon-separated list.
-    Undefined and infinity values can be replaced by using nan, inf and -inf (e.g. 1.0, 5, inf, -inf, 20, nan).
+    """Remove.
 
+    Remove values in a time series. The values to remove should be a
+    semicolon-separated list. Undefined and infinity values can be replaced by
+    using nan, inf and -inf (e.g. 1.0, 5, inf, -inf, 20, nan).
 
     Args:
         series: Time series
@@ -307,7 +324,8 @@ def remove(series: pd.Series, to_remove: Optional[List[float]] = None):
 
 @check_types
 def threshold(series: pd.Series, low: float = -np.inf, high: float = np.inf):
-    """Threshold
+    """Threshold.
+
     Indicates if the input series exceeds the lower and higher limits. The output series
     is 1.0 if the input is between the (inclusive) limits, and 0.0 otherwise.
 
@@ -329,7 +347,8 @@ def threshold(series: pd.Series, low: float = -np.inf, high: float = np.inf):
 
 
 def generate_step_series(flag: pd.Series) -> pd.Series:
-    """Step-wise time series
+    """Step-wise time series.
+
     Construct a step-wise time series (with 0-1 values) from a flag time series.
 
     Args:
@@ -400,7 +419,7 @@ def generate_step_series(flag: pd.Series) -> pd.Series:
 
 
 def create_series_from_timesteps(timesteps: List[timedelta]) -> pd.Series:
-    """Time series from timestamps
+    """Time series from timestamps.
 
     Create a time series which starts on the 2021-1-1 and contains data points
     with the provided timesteps in seconds. All values of the output series are zero.
@@ -410,9 +429,7 @@ def create_series_from_timesteps(timesteps: List[timedelta]) -> pd.Series:
 
     Returns:
         pd.Series: Time series
-
     """
-
     current = datetime(2021, 1, 1)
     timestamps = [current]
     for step in timesteps:
@@ -422,9 +439,9 @@ def create_series_from_timesteps(timesteps: List[timedelta]) -> pd.Series:
 
 
 def normality_assumption_test(
-    series: pd.Series, max_data_points: int = 5000, min_p_value: float = 0.05, min_W: float = 0.5
+    series: Union[pd.Series, np.array], max_data_points: int = 5000, min_p_value: float = 0.05, min_W: float = 0.5
 ) -> Tuple[float, float]:
-    """Test for normality assumption
+    """Test for normality assumption.
 
     This function performs a Shapiro-Wilk test to check if the data is normally distributed.
 
@@ -435,13 +452,15 @@ def normality_assumption_test(
             Default to 5000.
         min_p_value: Minimum p value.
             Probability of the time series not being normally distributed.
-            Default to 0.5.
+            Default to 0.05.
         min_W: Minimum W value.
             W is between 0 and 1, small values lead to a rejection of the
             normality assumption. Ref: https://www.nrc.gov/docs/ML1714/ML17143A100.pdf
             Default to 0.5.
+
     Raises:
         UserValueError: time series has more than the maximum number of datapoints allowed for this test.
+        UserValueError: time series is uniform and not normally distributed
         UserValueError: time series is not normally distributed.
     """
     if len(series) > max_data_points:
@@ -449,14 +468,16 @@ def normality_assumption_test(
 
     W, p_value = shapiro(series)
 
+    if p_value == 1.0 and W == 1.0:
+        raise UserValueError("This time series is uniform and not normally distributed")
     if p_value < min_p_value or W < min_W:
-        raise UserValueError("This time series is not normally distibuted")
+        raise UserValueError("This time series is not normally distributed")
 
     return  # type: ignore
 
 
 def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater") -> np.array:
-    """Z-scores Test
+    """Z-scores Test.
 
     This functions performs a z-scores test given a cutoff value and returns a binary time series.
 
@@ -468,6 +489,7 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
             Options:
                 "greater": the function will check if the z-scores are greater than the cutoff
                 "less": the function will check if the z-scores are less than the cutoff
+
     Returns:
          np.array: Binary np.array with the results of the test.
             1 values indicate that the test has passed.
@@ -483,7 +505,7 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
 def modified_z_scores_test(
     x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater"
 ) -> np.array:
-    """Z-scores Test
+    """Z-scores Test.
 
     This functions performs a modified z-scores test given a cutoff value and returns a binary time series.
 
@@ -494,11 +516,11 @@ def modified_z_scores_test(
             Options:
                 "greater": the function will check if the modified z-scores are greater than the cutoff
                 "less": the function will check if the modified z-scores are less than the cutoff
+
     Returns:
          np.array: Binary np.array with the results of the test.
             1 values indicate that the test has passed.
     """
-
     median = np.median(x)
     if (mad := np.median(np.abs(x - median))) == 0.0:
         modified_z_scores = np.zeros(len(x))
@@ -511,7 +533,7 @@ def modified_z_scores_test(
 def iqr_test(
     x: np.array, limit: Literal["upper", "lower"] = "upper", direction: Literal["greater", "less"] = "greater"
 ) -> np.array:
-    """Z-scores Test
+    """Z-scores Test.
 
     This functions performs a iqr test and returns a binary time series.
 
@@ -522,11 +544,11 @@ def iqr_test(
             Options:
                 "greater": the function will check if the values are greater than the cutoff limit.
                 "less": the function will check if the values are less than the cutoff limit.
+
     Returns:
          np.array: Binary np.array with the results of the test.
             1 values indicate that the test has passed.
     """
-
     percentile25 = np.quantile(x, 0.25)
     percentile75 = np.quantile(x, 0.75)
     iqr = percentile75 - percentile25
@@ -540,7 +562,7 @@ def iqr_test(
 
 
 def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "less"]) -> np.array:
-    """Threshold test
+    """Threshold test.
 
     This functions performs a threshold test based on a direction (greater than or less than).
 
@@ -551,6 +573,7 @@ def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "le
             Options:
                 "greater": the function will check if the values are greater than the cutoff limit.
                 "less": the function will check if the values are less than the cutoff limit.
+
     Returns:
          np.array: Binary np.array with the results of the test.
             1 values indicate that the test has passed.
