@@ -48,13 +48,11 @@ def register(
         deprecated: Flag is function is deprecated. Default: False
         changelog: Description on what has changed since the previous version. Default: None
     """
-
     # Test that the version numbering is valid
     Version(version)
 
     def register_decorator(func: Callable[..., Any]) -> Callable[..., Any]:
-        """Register a new versioned function"""
-
+        """Register a new versioned function."""
         key = name or func.__name__
 
         if version in _registered_funcs[key]:
@@ -73,24 +71,23 @@ def register(
 
 
 def get_registered_functions() -> List[str]:
-    """Return the list of registered function names"""
-
+    """Return the list of registered function names."""
     return list(_registered_funcs.keys())
 
 
 @check_types
 def get_versions(name: str) -> List[str]:
     """Return the list of available versions of a function name.
-    Sorted from low to highest version"""
 
+    Sorted from low to highest version
+    """
     versions = _registered_funcs[name].keys()
     return sorted(versions, key=Version)
 
 
 @check_types
 def get_name(func: Callable[..., Any]) -> str:
-    """Return the name with which the function was registered"""
-
+    """Return the name with which the function was registered."""
     try:
         return func.__versioning_name__  # type: ignore
     except AttributeError:
@@ -99,8 +96,10 @@ def get_name(func: Callable[..., Any]) -> str:
 
 @check_types
 def get_version(func: Callable[..., Any]) -> Optional[str]:
-    """Return the version of a function. If the function is not registered, None is returned"""
+    """Return the version of a function.
 
+    If the function is not registered, None is returned
+    """
     try:
         return func.__versioning_version__  # type: ignore
     except AttributeError:
@@ -109,15 +108,16 @@ def get_version(func: Callable[..., Any]) -> Optional[str]:
 
 @check_types
 def is_versioned(func: Callable[..., Any]) -> bool:
-    """Return true if the version is versioned"""
-
+    """Return true if the version is versioned."""
     return hasattr(func, "__versioning_version__")
 
 
 @check_types
 def is_deprecated(func: Callable[..., Any]) -> Optional[bool]:
-    """Return true if the version is deprecated. If the function is not registered, None is returned"""
+    """Return true if the version is deprecated.
 
+    If the function is not registered, None is returned
+    """
     try:
         return func.__versioning_deprecated__  # type: ignore
     except AttributeError:
@@ -126,8 +126,10 @@ def is_deprecated(func: Callable[..., Any]) -> Optional[bool]:
 
 @check_types
 def get_changelog(func: Callable[..., Any]) -> Optional[str]:
-    """Return changelog of this version. If the function is not registered, None is returned"""
+    """Return changelog of this version.
 
+    If the function is not registered, None is returned
+    """
     try:
         return func.__versioning_changelog__  # type: ignore
     except AttributeError:
@@ -137,8 +139,9 @@ def get_changelog(func: Callable[..., Any]) -> Optional[str]:
 @check_types
 def get(name: str, version: Optional[str] = None) -> Callable[..., Any]:
     """Return one of the versions of a function.
-    If version is None, the latest version is returned"""
 
+    If version is None, the latest version is returned
+    """
     if version is None:
         version = get_versions(name)[-1]
 
@@ -154,8 +157,9 @@ def run(
     name: str, version: Optional[str] = None, args: Optional[Sequence] = None, kwargs: Optional[dict] = None
 ) -> Any:
     """Run a version of a function.
-    If version is None, the latest version is executed"""
 
+    If version is None, the latest version is executed
+    """
     if args is None:
         args = []
     if kwargs is None:
